@@ -20,6 +20,9 @@ func init() {
 		"--schema), a subdir with a .skeema config file will be created. Each directory " +
 		"will be populated with .sql files containing CREATE statements for every " +
 		"table and routine in the schema.\n\n" +
+		"When operating on all schemas on the server, this command automatically skips pre-" +
+		"installed / system schemas (information_schema, performance_schema, mysql, sys, " +
+		"test).\n\n" +
 		"You may optionally pass an environment name as a command-line arg. This will affect " +
 		"which section of .skeema config files the host-related options are written to. " +
 		"For example, running `skeema init staging` will add config directives to the " +
@@ -160,7 +163,7 @@ func createHostOptionFile(cfg *mybase.Config, hostDir *fs.Dir, inst *tengo.Insta
 	if flavor := inst.Flavor(); flavor.Known() {
 		hostOptionFile.SetOptionValue(environment, "flavor", flavor.Family().String())
 	} else {
-		log.Warnf(`Unable to automatically determine database server's vendor/version. To set manually, use the "flavor" option in ` + hostOptionFile.Path())
+		log.Warn(`Unable to automatically determine database server's vendor/version. To set manually, use the "flavor" option in ` + hostOptionFile.Path())
 	}
 	for optionName := range cfg.CLI.OptionValues {
 		if persistOptionAlongsideHost(optionName) {
@@ -237,7 +240,7 @@ func PopulateSchemaDir(s *tengo.Schema, parentDir *fs.Dir, makeSubdir bool) erro
 	}
 
 	if ignoreSchema, err := parentDir.Config.GetRegexp("ignore-schema"); err != nil {
-		return NewExitValue(CodeBadConfig, err.Error())
+		return WrapExitCode(CodeBadConfig, err)
 	} else if ignoreSchema != nil && ignoreSchema.MatchString(s.Name) {
 		log.Debugf("Skipping schema %s because ignore-schema='%s'", s.Name, ignoreSchema)
 		return nil
