@@ -1,6 +1,7 @@
 package main
 
 import (
+	"errors"
 	"fmt"
 
 	log "github.com/sirupsen/logrus"
@@ -20,11 +21,11 @@ func init() {
 		"generate an error, a warning, or be ignored entirely. Statements that contain " +
 		"invalid SQL, or otherwise return an error from the database, are always flagged " +
 		"as linter errors.\n\n" +
-		"By default, this command also reformats statements to their canonical form, " +
+		"By default, this command also reformats CREATE statements to their canonical form, " +
 		"just like `skeema format`.\n\n" +
-		"This command relies on accessing database instances to test the SQL DDL in a " +
+		"This command relies on accessing a database server to test the SQL DDL in a " +
 		"temporary location. See the --workspace option for more information.\n\n" +
-		"You may optionally pass an environment name as a CLI arg. This will affect " +
+		"You may optionally pass an environment name as a command-line arg. This will affect " +
 		"which section of .skeema config files is used for linter configuration and " +
 		"workspace selection. For example, running `skeema lint staging` will " +
 		"apply config directives from the [staging] section of config files, as well as " +
@@ -122,10 +123,15 @@ func lintWalker(dir *fs.Dir, maxDepth int) *linter.Result {
 // returned. This function does not recurse into subdirs.
 func lintDir(dir *fs.Dir) *linter.Result {
 	opts, err := linter.OptionsForDir(dir)
-	opts.StripAnnotationNewlines = !util.StderrIsTerminal()
-	if err != nil && len(dir.LogicalSchemas) > 0 {
+	if err != nil {
+		// If there's nothing to lint here anyway, return an empty result instead
+		// of surfacing the error on what may be an empty intermediate directory.
+		if len(dir.LogicalSchemas) == 0 {
+			return &linter.Result{}
+		}
 		return linter.BadConfigResult(dir, err)
 	}
+	opts.StripAnnotationNewlines = !util.StderrIsTerminal()
 
 	// Get workspace options for dir. This involves connecting to the first defined
 	// instance, so that any auto-detect-related settings work properly. However,
@@ -152,6 +158,11 @@ func lintDir(dir *fs.Dir) *linter.Result {
 		// workspace
 		wsSchema, err := workspace.ExecLogicalSchema(logicalSchema, wsOpts)
 		if err != nil {
+			// Since `skeema lint` is often used in Docker-based CI, add extra
+			// explanatory text if the error was caused by lack of Docker CLI on PATH
+			if errors.Is(err, tengo.ErrNoDockerCLI) {
+				err = fmt.Errorf("%w\nSkeema v1.11+ no longer includes a built-in Docker client. If you are using workspace=docker while also running `skeema` itself in a container, be sure to put a Linux `docker` client CLI binary in the container as well.\nFor more information, see https://github.com/skeema/skeema/issues/186#issuecomment-1648483625", err)
+			}
 			result.Fatal(err)
 			continue
 		}
