@@ -2,7 +2,6 @@ package linter
 
 import (
 	"fmt"
-	"strings"
 
 	"github.com/skeema/skeema/internal/tengo"
 )
@@ -19,10 +18,10 @@ func init() {
 func hasFloatChecker(table *tengo.Table, createStatement string, _ *tengo.Schema, _ *Options) []Note {
 	results := make([]Note, 0)
 	for _, col := range table.Columns {
-		if strings.HasPrefix(col.TypeInDB, "float") || strings.HasPrefix(col.TypeInDB, "double") {
+		if col.Type.Base == "float" || col.Type.Base == "double" {
 			message := fmt.Sprintf(
 				"Column %s of %s is using type %s. Floating-point types can only store approximate values. For use-cases requiring exact precision, such as monetary data, use the decimal type instead.",
-				col.Name, table.ObjectKey(), col.TypeInDB,
+				col.Name, table.ObjectKey(), col.Type.Base,
 			)
 			results = append(results, Note{
 				LineOffset: FindColumnLineOffset(col, createStatement),
