@@ -108,8 +108,14 @@ func TestInstanceBuildParamString(t *testing.T) {
 	assertParamString("", "param1=value1", "param1=value1")
 	assertParamString("param1=value1", "param1=value1", "param1=value1")
 	assertParamString("param1=value1", "param1=hello", "param1=hello")
-	assertParamString("param1=value1&readTimeout=5s&interpolateParams=0", "param2=value2", "param1=value1&readTimeout=5s&interpolateParams=0&param2=value2")
-	assertParamString("param1=value1&readTimeout=5s&interpolateParams=0", "param1=value3", "param1=value3&readTimeout=5s&interpolateParams=0")
+	assertParamString("param1=value1&timeout=5s&interpolateParams=0", "param2=value2", "param1=value1&timeout=5s&interpolateParams=0&param2=value2")
+	assertParamString("param1=value1&timeout=5s&interpolateParams=0", "param1=value3", "param1=value3&timeout=5s&interpolateParams=0")
+
+	// Test special interactions between readTimeout, lock_wait_timeout, innodb_lock_wait_timeout
+	assertParamString("lock_wait_timeout=20", "", "lock_wait_timeout=20")
+	assertParamString("lock_wait_timeout=20", "readTimeout=10s", "readTimeout=10s&lock_wait_timeout=9&innodb_lock_wait_timeout=LEAST(9,CONVERT(@@innodb_lock_wait_timeout,SIGNED))")
+	assertParamString("readTimeout=10500ms", "innodb_lock_wait_timeout=7", "readTimeout=10500ms&innodb_lock_wait_timeout=7&lock_wait_timeout=LEAST(9,CONVERT(@@lock_wait_timeout,SIGNED))")
+	assertParamString("readTimeout=2.5s", "readTimeout=1.5s", "readTimeout=2s&lock_wait_timeout=1&innodb_lock_wait_timeout=1")
 }
 
 func TestInstanceIntrospectionParams(t *testing.T) {
@@ -597,7 +603,7 @@ func (s TengoIntegrationSuite) TestInstanceDropSchema(t *testing.T) {
 	s.SourceTestSQL(t, "integration-ext.sql", "rows.sql")
 
 	opts := BulkDropOptions{
-		MaxConcurrency:  10,
+		ChunkSize:       6,
 		OnlyIfEmpty:     true,
 		PartitionsFirst: true,
 	}
@@ -634,8 +640,8 @@ func (s TengoIntegrationSuite) TestInstanceDropTablesInSchemaByRef(t *testing.T)
 		t.Fatal("Assertion failure: schema `testing` has no tables to start")
 	}
 	opts := BulkDropOptions{
-		MaxConcurrency: 10,
-		Schema:         schema,
+		ChunkSize: 3,
+		Schema:    schema,
 	}
 	if err := s.d.DropTablesInSchema("testing", opts); err != nil {
 		t.Fatalf("Unexpected error from DropTablesInSchema: %v", err)
@@ -651,39 +657,6 @@ func (s TengoIntegrationSuite) TestInstanceDropTablesInSchemaByRef(t *testing.T)
 	}
 }
 
-func (s TengoIntegrationSuite) TestInstanceDropTablesDeadlock(t *testing.T) {
-	// With the new data dictionary, attempting to drop 2 tables concurrently can
-	// deadlock if the tables have a foreign key constraint between them. This
-	// deadlock did not occur in prior releases.
-	if !s.d.Flavor().MinMySQL(8) {
-		t.Skip("Test only relevant for flavors that have the new data dictionary")
-	}
-
-	s.SourceTestSQL(t, "integration-ext.sql", "rows.sql")
-
-	db, err := s.d.CachedConnectionPool("", "foreign_key_checks=0")
-	if err != nil {
-		t.Fatalf("Unable to connect to DockerizedInstance: %s", err)
-	}
-
-	// Add a FK relation, drop all tables in the schema, and then restore the
-	// test database to its previous state. Without the fix in DropTablesInSchema,
-	// this tends to hit a deadlock within just a few loop iterations.
-	opts := BulkDropOptions{MaxConcurrency: 10}
-	for n := 0; n < 10; n++ {
-		_, err = db.Exec("ALTER TABLE testing.actor_in_film ADD CONSTRAINT actor FOREIGN KEY (actor_id) REFERENCES testing.actor (actor_id)")
-		if err != nil {
-			t.Fatalf("Error running query on DockerizedInstance: %s", err)
-		}
-		if err = s.d.DropTablesInSchema("testing", opts); err != nil {
-			t.Fatalf("Error dropping tables: %s", err)
-		}
-		if err = s.BeforeTest(""); err != nil {
-			t.Fatalf("Error nuking and re-sourcing data: %s", err)
-		}
-	}
-}
-
 // TestInstanceDropTablesSkipsViews tests the behavior of
 // Instance.DropTablesInSchema when views are present in the schema. Although
 // this package does not support views, presence of them should not break
@@ -734,7 +707,7 @@ func (s TengoIntegrationSuite) TestInstanceDropTablesSkipsViews(t *testing.T) {
 	// will error on a view; and even before that, since we use OnlyIfEmpty, the
 	// SELECT on a view with a bad definer will also error.
 	opts := BulkDropOptions{
-		MaxConcurrency:  10,
+		ChunkSize:       5,
 		OnlyIfEmpty:     true,
 		PartitionsFirst: true,
 	}
@@ -750,7 +723,7 @@ func (s TengoIntegrationSuite) TestInstanceDropRoutinesInSchema(t *testing.T) {
 		t.Fatal("Assertion failure: schema `testing` has no routines to start")
 	}
 	opts := BulkDropOptions{
-		MaxConcurrency: 10,
+		ChunkSize: 3,
 	}
 	if err := s.d.DropRoutinesInSchema("testing", opts); err != nil {
 		t.Fatalf("Unexpected error from DropRoutinesInSchema: %v", err)
@@ -777,8 +750,8 @@ func (s TengoIntegrationSuite) TestInstanceDropRoutinesInSchemaByRef(t *testing.
 		t.Fatal("Assertion failure: schema `testing` has no routines to start")
 	}
 	opts := BulkDropOptions{
-		MaxConcurrency: 10,
-		Schema:         schema,
+		ChunkSize: 3,
+		Schema:    schema,
 	}
 	if err := s.d.DropRoutinesInSchema("testing", opts); err != nil {
 		t.Fatalf("Unexpected error from DropRoutinesInSchema: %v", err)
