@@ -28,12 +28,11 @@ func querySchemaTables(ctx context.Context, db *sqlx.DB, schema string, flavor F
 
 	g, subCtx := errgroup.WithContext(ctx)
 
-	for n := range tables {
-		t := tables[n] // avoid issues with goroutines and loop iterator values
+	for _, t := range tables {
 		g.Go(func() (err error) {
 			t.CreateStatement, err = showCreateTable(subCtx, db, t.Name)
 			if err != nil {
-				err = fmt.Errorf("Error executing SHOW CREATE TABLE for %s.%s: %s", EscapeIdentifier(schema), EscapeIdentifier(t.Name), err)
+				err = fmt.Errorf("Error executing SHOW CREATE TABLE for %s.%s: %w", EscapeIdentifier(schema), EscapeIdentifier(t.Name), err)
 			}
 			return err
 		})
@@ -125,9 +124,9 @@ func querySchemaTables(ctx context.Context, db *sqlx.DB, schema string, flavor F
 		if t.NextAutoIncrement == 0 && t.HasAutoIncrement() {
 			t.NextAutoIncrement = 1
 		}
-		// Remove create options which don't affect InnoDB
+		// Remove column and index attributes which don't affect InnoDB
 		if t.Engine == "InnoDB" {
-			t.CreateStatement = NormalizeCreateOptions(t.CreateStatement)
+			t.CreateStatement = StripNonInnoAttributes(t.CreateStatement)
 		}
 		// Index order is unpredictable with new MySQL 8 data dictionary, so reorder
 		// indexes based on parsing SHOW CREATE TABLE if needed
@@ -174,6 +173,11 @@ func querySchemaTables(ctx context.Context, db *sqlx.DB, schema string, flavor F
 		if len(t.Checks) > 0 {
 			fixChecks(t, flavor)
 		}
+		// MariaDB's VECTOR indexes can have M and/or DISTANCE attributes, which
+		// aren't exposed anywhere in I_S
+		if flavor.MinMariaDB(11, 7) && strings.Contains(t.CreateStatement, "VECTOR KEY") {
+			fixVectorIndexes(t, flavor)
+		}
 
 		// Compare what we expect the create DDL to be, to determine if we support
 		// diffing for the table. (No need to remove next AUTO_INCREMENT from this
@@ -292,27 +296,31 @@ func queryColumnsInSchema(ctx context.Context, db *sqlx.DB, schema string, flavo
 	}
 	columnsByTableName := make(map[string][]*Column)
 	for _, rawColumn := range rawColumns {
+		// MariaDB includes compression attribute in column type; remove it BEFORE
+		// parsing the column type
+		var mariaCompressedColumn bool
+		if mariaCompressedColMarker != "" {
+			rawColumn.Type, _, mariaCompressedColumn = strings.Cut(rawColumn.Type, mariaCompressedColMarker)
+		}
+
 		col := &Column{
 			Name:          rawColumn.Name,
-			TypeInDB:      rawColumn.Type,
+			Type:          ParseColumnType(rawColumn.Type),
 			Nullable:      strings.EqualFold(rawColumn.IsNullable, "YES"),
 			AutoIncrement: strings.Contains(rawColumn.Extra, "auto_increment"),
 			Comment:       rawColumn.Comment,
 			Invisible:     strings.Contains(rawColumn.Extra, "INVISIBLE"),
 		}
+		if mariaCompressedColumn {
+			col.Compression = "COMPRESSED"
+		}
+
 		// If db was upgraded from a pre-8.0.19 version (but still 8.0+) to 8.0.19+,
 		// I_S may still contain int display widths even though SHOW CREATE TABLE
 		// omits them. Strip to avoid incorrectly flagging the table as unsupported
 		// for diffs.
 		if stripDisplayWidth {
-			col.TypeInDB, _ = StripDisplayWidth(col.TypeInDB) // safe/no-op if already no int display width
-		}
-		if mariaCompressedColMarker != "" {
-			if pos := strings.Index(col.TypeInDB, mariaCompressedColMarker); pos > -1 {
-				// MariaDB includes compression attribute in column type; remove it
-				col.Compression = "COMPRESSED"
-				col.TypeInDB = col.TypeInDB[0:pos]
-			}
+			col.Type.StripDisplayWidth() // safe/no-op if already no int display width
 		}
 		if rawColumn.GenerationExpr.Valid {
 			col.GenerationExpr = rawColumn.GenerationExpr.String
@@ -325,7 +333,7 @@ func queryColumnsInSchema(ctx context.Context, db *sqlx.DB, schema string, flavo
 			// Recent versions of MySQL do allow default *expressions* for these col
 			// types, but 8.0.13-8.0.22 erroneously omit them from I_S, so we need to
 			// catch this situation and parse from SHOW CREATE later.
-			if !flavor.MinMariaDB(10, 2) && (strings.HasSuffix(col.TypeInDB, "blob") || strings.HasSuffix(col.TypeInDB, "text")) {
+			if !flavor.MinMariaDB(10, 2) && (strings.HasSuffix(col.Type.Base, "blob") || strings.HasSuffix(col.Type.Base, "text")) {
 				allowNullDefault = false
 				if strings.Contains(rawColumn.Extra, "DEFAULT_GENERATED") {
 					col.Default = "(!!!BLOBDEFAULT!!!)"
@@ -348,16 +356,16 @@ func queryColumnsInSchema(ctx context.Context, db *sqlx.DB, schema string, flavo
 			// SHOW CREATE TABLE in MySQL. However MySQL I_S data has some issues for
 			// default expressions. The most common one is fixed here, and if additional
 			// mismatches remain, they get corrected by fixDefaultExpression later on.
-			col.Default = fmt.Sprintf("(%s)", strings.ReplaceAll(rawColumn.Default.String, "\\'", "'"))
+			col.Default = "(" + strings.ReplaceAll(rawColumn.Default.String, "\\'", "'") + ")"
 		} else {
-			col.Default = fmt.Sprintf("'%s'", EscapeValueForCreateTable(rawColumn.Default.String))
+			col.Default = "'" + EscapeValueForCreateTable(rawColumn.Default.String) + "'"
 		}
 		if matches := reExtraOnUpdate.FindStringSubmatch(rawColumn.Extra); matches != nil {
 			col.OnUpdate = matches[1]
 			// Some flavors omit fractional precision from ON UPDATE in
 			// information_schema only, despite it being present everywhere else
 			if openParen := strings.IndexByte(rawColumn.Type, '('); openParen > -1 && !strings.Contains(col.OnUpdate, "(") {
-				col.OnUpdate = fmt.Sprintf("%s%s", col.OnUpdate, rawColumn.Type[openParen:])
+				col.OnUpdate = col.OnUpdate + rawColumn.Type[openParen:]
 			}
 		}
 		if rawColumn.Collation.Valid { // only text-based column types have a notion of charset and collation
@@ -444,11 +452,11 @@ func queryIndexesInSchema(ctx context.Context, db *sqlx.DB, schema string, flavo
 		} else {
 			secondaryIndexesByTableName[rawIndex.TableName] = append(secondaryIndexesByTableName[rawIndex.TableName], index)
 		}
-		fullNameStr := fmt.Sprintf("%s.%s.%s", schema, rawIndex.TableName, rawIndex.Name)
+		fullNameStr := schema + "." + rawIndex.TableName + "." + rawIndex.Name
 		indexesByTableAndName[fullNameStr] = index
 	}
 	for _, rawIndex := range rawIndexes {
-		fullIndexNameStr := fmt.Sprintf("%s.%s.%s", schema, rawIndex.TableName, rawIndex.Name)
+		fullIndexNameStr := schema + "." + rawIndex.TableName + "." + rawIndex.Name
 		index, ok := indexesByTableAndName[fullIndexNameStr]
 		if !ok {
 			panic(fmt.Errorf("Cannot find index %s", fullIndexNameStr))
@@ -684,7 +692,7 @@ func fixCreateOptionsOrder(t *Table, flavor Flavor) {
 	template = strings.Replace(template, t.CreateOptions, "!!!CREATEOPTS!!!", 1)
 	template = regexp.QuoteMeta(template)
 	template = strings.Replace(template, "!!!CREATEOPTS!!!", "(.+)", 1)
-	re := regexp.MustCompile(fmt.Sprintf("^%s$", template))
+	re := regexp.MustCompile("^" + template + "$")
 
 	for _, line := range strings.Split(t.CreateStatement, "\n") {
 		if strings.HasPrefix(line, ") ENGINE=") {
@@ -826,7 +834,12 @@ func fixFulltextIndexParsers(t *Table, flavor Flavor) {
 		if idx.Type == "FULLTEXT" {
 			// Obtain properly-formatted index definition without parser clause, and
 			// then build a regex from this which captures the parser name.
-			template := fmt.Sprintf("%s /*!50100 WITH PARSER ", idx.Definition(flavor))
+			var template string
+			if flavor.MinMariaDB(11, 7) {
+				template = idx.Definition(flavor) + " WITH PARSER "
+			} else {
+				template = idx.Definition(flavor) + " /*!50100 WITH PARSER "
+			}
 			template = regexp.QuoteMeta(template)
 			template += "`([^`]+)`"
 			re := regexp.MustCompile(template)
@@ -857,7 +870,7 @@ func fixDefaultExpression(t *Table, flavor Flavor) {
 		var matcher string
 		if col.Default[0] == '(' {
 			matcher = `.+DEFAULT (\(.+\))`
-		} else if strings.HasPrefix(col.Default, "'0x") && strings.Contains(col.TypeInDB, "binary") {
+		} else if strings.HasPrefix(col.Default, "'0x") && (col.Type.Base == "binary" || col.Type.Base == "varbinary") {
 			matcher = `.+DEFAULT ('(''|[^'])*')`
 		} else {
 			continue
@@ -943,7 +956,7 @@ func fixChecks(t *Table, flavor Flavor) {
 		cc.Clause = "!!!CHECKCLAUSE!!!"
 		template := cc.Definition(flavor)
 		template = regexp.QuoteMeta(template)
-		template = fmt.Sprintf("%s,?\n", strings.Replace(template, cc.Clause, "(.+?)", 1))
+		template = strings.Replace(template, cc.Clause, "(.+?)", 1) + ",?\n"
 		re := regexp.MustCompile(template)
 		matches := re.FindStringSubmatch(t.CreateStatement)
 		if matches != nil {
@@ -951,3 +964,25 @@ func fixChecks(t *Table, flavor Flavor) {
 		}
 	}
 }
+
+// fixVectorIndexes examines SHOW CREATE TABLE to obtain the optional M and
+// DISTANCE attributes for MariaDB vector indexes. These attributes are not
+// currently exposed in information_schema.
+func fixVectorIndexes(t *Table, flavor Flavor) {
+	for _, idx := range t.SecondaryIndexes {
+		if idx.Type != "VECTOR" {
+			continue
+		}
+		definition := idx.Definition(flavor)
+		if indexStartPos := strings.Index(t.CreateStatement, definition+" "); indexStartPos > -1 {
+			attribStart := indexStartPos + len(definition) + 1
+			if newlinePos := strings.IndexByte(t.CreateStatement[attribStart:], '\n'); newlinePos > -1 {
+				attribEnd := attribStart + newlinePos
+				if t.CreateStatement[attribEnd-1] == ',' {
+					attribEnd--
+				}
+				idx.Attributes = t.CreateStatement[attribStart:attribEnd]
+			}
+		}
+	}
+}
