@@ -275,27 +275,29 @@ func TestColumnCompression(t *testing.T) {
 // TestFixFulltextIndexParsers confirms CREATE TABLE parsing for WITH PARSER
 // clauses works properly.
 func TestFixFulltextIndexParsers(t *testing.T) {
-	flavor := ParseFlavor("mysql:5.7")
-	table := anotherTableForFlavor(flavor)
-	if table.SecondaryIndexes[0].Type != "BTREE" || table.SecondaryIndexes[0].FullTextParser != "" {
-		t.Fatal("Test fixture has changed without corresponding update to this test's logic")
-	}
+	for _, flavorString := range []string{"mysql:5.7", "mariadb:11.7"} {
+		flavor := ParseFlavor(flavorString)
+		table := anotherTableForFlavor(flavor)
+		if table.SecondaryIndexes[0].Type != "BTREE" || table.SecondaryIndexes[0].FullTextParser != "" {
+			t.Fatal("Test fixture has changed without corresponding update to this test's logic")
+		}
 
-	// Confirm no parser = no change from fix
-	table.SecondaryIndexes[0].Type = "FULLTEXT"
-	table.CreateStatement = table.GeneratedCreateStatement(flavor)
-	fixFulltextIndexParsers(&table, flavor)
-	if table.SecondaryIndexes[0].FullTextParser != "" {
-		t.Errorf("fixFulltextIndexParsers unexpectedly set parser to %q instead of %q", table.SecondaryIndexes[0].FullTextParser, "")
-	}
+		// Confirm no parser = no change from fix
+		table.SecondaryIndexes[0].Type = "FULLTEXT"
+		table.CreateStatement = table.GeneratedCreateStatement(flavor)
+		fixFulltextIndexParsers(&table, flavor)
+		if table.SecondaryIndexes[0].FullTextParser != "" {
+			t.Errorf("fixFulltextIndexParsers unexpectedly set parser to %q instead of %q", table.SecondaryIndexes[0].FullTextParser, "")
+		}
 
-	// Confirm parser extracted correctly from fix
-	table.SecondaryIndexes[0].FullTextParser = "ngram"
-	table.CreateStatement = table.GeneratedCreateStatement(flavor)
-	table.SecondaryIndexes[0].FullTextParser = ""
-	fixFulltextIndexParsers(&table, flavor)
-	if table.SecondaryIndexes[0].FullTextParser != "ngram" {
-		t.Errorf("fixFulltextIndexParsers unexpectedly set parser to %q instead of %q", table.SecondaryIndexes[0].FullTextParser, "ngram")
+		// Confirm parser extracted correctly from fix
+		table.SecondaryIndexes[0].FullTextParser = "ngram"
+		table.CreateStatement = table.GeneratedCreateStatement(flavor)
+		table.SecondaryIndexes[0].FullTextParser = ""
+		fixFulltextIndexParsers(&table, flavor)
+		if table.SecondaryIndexes[0].FullTextParser != "ngram" {
+			t.Errorf("fixFulltextIndexParsers unexpectedly set parser to %q instead of %q", table.SecondaryIndexes[0].FullTextParser, "ngram")
+		}
 	}
 }
 
@@ -335,6 +337,7 @@ func TestFixShowCharSets(t *testing.T) {
   ~f~ char(10) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
   ~g~ char(10) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COLLATE=utf8_unicode_ci`, "~", "`")
+	char10 := ParseColumnType("char(10)")
 	table := &Table{
 		Name:          "many_permutations",
 		Engine:        "InnoDB",
@@ -342,13 +345,13 @@ func TestFixShowCharSets(t *testing.T) {
 		Collation:     "utf8_unicode_ci",
 		ShowCollation: true,
 		Columns: []*Column{
-			{Name: "a", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_unicode_ci", ShowCharSet: false, ShowCollation: true},
-			{Name: "b", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_swedish_ci", ShowCharSet: true, ShowCollation: false},
-			{Name: "c", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_swedish_ci", ShowCharSet: true, ShowCollation: false},
-			{Name: "d", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_bin", ShowCharSet: true, ShowCollation: true},
-			{Name: "e", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_general_ci", ShowCharSet: true, ShowCollation: false},
-			{Name: "f", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_general_ci", ShowCharSet: true, ShowCollation: false},
-			{Name: "g", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_unicode_ci", ShowCharSet: false, ShowCollation: true},
+			{Name: "a", Type: char10, Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_unicode_ci", ShowCharSet: false, ShowCollation: true},
+			{Name: "b", Type: char10, Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_swedish_ci", ShowCharSet: true, ShowCollation: false},
+			{Name: "c", Type: char10, Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_swedish_ci", ShowCharSet: true, ShowCollation: false},
+			{Name: "d", Type: char10, Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_bin", ShowCharSet: true, ShowCollation: true},
+			{Name: "e", Type: char10, Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_general_ci", ShowCharSet: true, ShowCollation: false},
+			{Name: "f", Type: char10, Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_general_ci", ShowCharSet: true, ShowCollation: false},
+			{Name: "g", Type: char10, Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_unicode_ci", ShowCharSet: false, ShowCollation: true},
 		},
 		CreateStatement: stmt,
 	}
@@ -375,13 +378,13 @@ func TestFixShowCharSets(t *testing.T) {
 	table.Collation = "latin1_swedish_ci"
 	table.ShowCollation = false
 	table.Columns = []*Column{
-		{Name: "a", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_bin", ShowCharSet: true, ShowCollation: true},
-		{Name: "b", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_swedish_ci", ShowCharSet: false, ShowCollation: false},
-		{Name: "c", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_swedish_ci", ShowCharSet: false, ShowCollation: false},
-		{Name: "d", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_bin", ShowCharSet: true, ShowCollation: true},
-		{Name: "e", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_general_ci", ShowCharSet: true, ShowCollation: false},
-		{Name: "f", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_general_ci", ShowCharSet: true, ShowCollation: false},
-		{Name: "g", TypeInDB: "char(10)", Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_unicode_ci", ShowCharSet: true, ShowCollation: true},
+		{Name: "a", Type: char10, Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_bin", ShowCharSet: true, ShowCollation: true},
+		{Name: "b", Type: char10, Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_swedish_ci", ShowCharSet: false, ShowCollation: false},
+		{Name: "c", Type: char10, Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_swedish_ci", ShowCharSet: false, ShowCollation: false},
+		{Name: "d", Type: char10, Nullable: true, Default: "NULL", CharSet: "latin1", Collation: "latin1_bin", ShowCharSet: true, ShowCollation: true},
+		{Name: "e", Type: char10, Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_general_ci", ShowCharSet: true, ShowCollation: false},
+		{Name: "f", Type: char10, Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_general_ci", ShowCharSet: true, ShowCollation: false},
+		{Name: "g", Type: char10, Nullable: true, Default: "NULL", CharSet: "utf8", Collation: "utf8_unicode_ci", ShowCharSet: true, ShowCollation: true},
 	}
 
 	// Verify initial setup: generated create should differ from CreateStatement
