@@ -7,7 +7,7 @@ CREATE TABLE prange (
 	customer_id int unsigned NOT NULL,
 	info text,
 	PRIMARY KEY (id, customer_id)
-) ENGINE=InnoDB ROW_FORMAT=REDUNDANT PARTITION BY RANGE (customer_id) (
+) ENGINE=InnoDB DEFAULT CHARACTER SET latin1 COLLATE latin1_swedish_ci ROW_FORMAT=REDUNDANT PARTITION BY RANGE (customer_id) (
 	PARTITION p0 VALUES LESS THAN (123),
 	PARTITION p1 VALUES LESS THAN (456),
 	PARTITION p2 VALUES LESS THAN MAXVALUE
