@@ -16,7 +16,7 @@ const rootDesc = "Skeema is a declarative schema management system for MySQL and
 
 // Globals overridden by GoReleaser's ldflags
 var (
-	version = "1.12.2"
+	version = "1.12.3"
 	commit  = "unknown"
 	date    = "unknown"
 )
@@ -38,12 +38,12 @@ func main() {
 	var cfg *mybase.Config
 	cfg, err := mybase.ParseCLI(CommandSuite, os.Args)
 	if err != nil {
-		Exit(NewExitValue(CodeBadConfig, err.Error()))
+		Exit(WrapExitCode(CodeBadConfig, err))
 	}
 
 	util.AddGlobalConfigFiles(cfg)
 	if err := util.ProcessSpecialGlobalOptions(cfg); err != nil {
-		Exit(NewExitValue(CodeBadConfig, err.Error()))
+		Exit(WrapExitCode(CodeBadConfig, err))
 	}
 
 	err = cfg.HandleCommand()
